---

slug: /character-concatenation-operators
---

# Character concatenation operators

seekdb supports character concatenation operators.

The following table describes the character concatenation operators supported in the current version of seekdb.

| Operator | Operand | Description |
|------|-----|-------|
| `||` | Binary | Concatenates strings |

The `||` operator can be used as a logical OR operator, and this behavior is controlled by the `sql_mode` parameter:

* If `sql_mode` contains `PIPES_AS_CONCAT`, `||` is a character concatenation operator.

* If `sql_mode` does not contain `PIPES_AS_CONCAT`, `||` is a logical OR operator.